@@ -2769,21 +2769,14 @@ bool GParted_Core::commit_to_os( std::time_t timeout )
 		//  bug #604298 - Failure to inform kernel of partition changes
 		//  If not successful the first time, try one more time.
 		if ( ! succes )
+		{
+			sleep( 1 ) ;
 			succes = ped_disk_commit_to_os( lp_disk ) ;
+		}
 	}
 
 	settle_device( timeout ) ;
 
-//	//FIXME:  Work around to try to alleviate problems caused by
-//	//  bug #604298 - Failure to inform kernel of partition changes
-//	if ( ! dmraid .is_dmraid_device( lp_disk ->dev ->path ) &&
-//	     ! Glib::find_program_in_path( "blockdev" ) .empty()
-//	   )
-//	{
-//		Utils::execute_command( "blockdev --rereadpt " + Glib::ustring( lp_disk ->dev ->path ) ) ;
-//		settle_device( timeout ) ;
-//	}
-
 	return succes ;
 }
 
